**Table of Contents**  *generated with [DocToc](https://github.com/thlorenz/doctoc)*

- [Infrastructure](#infrastructure)
  - [Google Cloud Logging](#google-cloud-logging)
  - [Google Cloud Storage](#google-cloud-storage)


# Infrastructure

**A facade for interacting with core services such as Google Cloud Storage, Mongo DB etc.**

<br>


## Google Cloud Logging

Redirect python logs to [Stackdriver](https://cloud.google.com/stackdriver/).

<br>

## Google Cloud Storage

Upload object to google storage.

<br>



